==> resteasy-microprofile-parent-1.0.0.Final-source-release.zip: resteasy-microprofile-parent-1.0.0.Final/testsuite/integration-tests/src/test/java/org/jboss/resteasy/microprofile/test/client/integration/resource/HeaderPropagator.java <==
/*
 * JBoss, Home of Professional Open Source.
 *
 * Copyright 2021 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.resteasy.microprofile.test.client.integration.resource;

import java.util.List;

import javax.ws.rs.core.HttpHeaders;
import javax.ws.rs.core.MultivaluedMap;

import org.eclipse.microprofile.rest.client.ext.ClientHeadersFactory;
import org.jboss.resteasy.core.ResteasyContext;
import org.junit.Assert;

public class HeaderPropagator implements ClientHeadersFactory {
    @Override
    public MultivaluedMap<String, String> update(MultivaluedMap<String, String> containerRequestHeaders,
            MultivaluedMap<String, String> clientRequestHeaders) {
        Assert.assertNull(ResteasyContext.getContextData(HttpHeaders.class));
        List<String> prop = containerRequestHeaders.get("X-Propagated");
        if (prop != null)
            clientRequestHeaders.addAll("X-Propagated", prop);
        return clientRequestHeaders;
    }
}

==> resteasy-microprofile-parent-2.1.4.Final-source-release.zip: resteasy-microprofile-parent-2.1.4.Final/testsuite/integration-tests/src/test/java/org/jboss/resteasy/microprofile/test/client/integration/resource/HeaderPropagator.java <==
/*
 * JBoss, Home of Professional Open Source.
 *
 * Copyright 2021 Red Hat, Inc., and individual contributors
 * as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.jboss.resteasy.microprofile.test.client.integration.resource;

import java.util.List;

import jakarta.ws.rs.core.HttpHeaders;
import jakarta.ws.rs.core.MultivaluedMap;

import org.eclipse.microprofile.rest.client.ext.ClientHeadersFactory;
import org.jboss.resteasy.core.ResteasyContext;
import org.junit.Assert;

public class HeaderPropagator implements ClientHeadersFactory {
    @Override
    public MultivaluedMap<String, String> update(MultivaluedMap<String, String> containerRequestHeaders,
            MultivaluedMap<String, String> clientRequestHeaders) {
        Assert.assertNull(ResteasyContext.getContextData(HttpHeaders.class));
        List<String> prop = containerRequestHeaders.get("X-Propagated");
        if (prop != null)
            clientRequestHeaders.addAll("X-Propagated", prop);
        return clientRequestHeaders;
    }
}
